@@ -36,3 +36,11 @@ test_that("ard_stats_kruskal_test() works", {
       ard_stats_kruskal_test(by = ARM, variable = c(AGE, BMIBL))
   )
 })
+
+test_that("ard_stats_kruskal_test() follows ard structure", {
+  expect_silent(
+    cards::ADSL |>
+      ard_stats_kruskal_test(by = ARM, variable = BMIBL) |>
+      cards::check_ard_structure()
+  )
+})
