@@ -27,3 +27,10 @@ test_that("ard_stats_oneway_test() works", {
       head(3)
   )
 })
+
+test_that("ard_stats_oneway_test() follows ard structure", {
+  expect_silent(
+    ard_stats_oneway_test(AGE ~ ARM, data = cards::ADSL) |>
+      cards::check_ard_structure()
+  )
+})
