@@ -47,6 +47,20 @@ test_that("ard_stats_wilcox_test_onesample() works", {
       cards::ADSL,
       variables = character(0)
     ),
-    dplyr::tibble()
+    dplyr::tibble() |> cards::as_card()
+  )
+})
+
+test_that("ard_stats_wilcox_test_onesample() follows ard structure", {
+  expect_silent(
+    ard_stats_wilcox_test_onesample(
+      cards::ADSL,
+      variables = AGE,
+      by = ARM,
+      conf.level = 0.9,
+      conf.int = TRUE,
+      mu = 1
+    ) |>
+      cards::check_ard_structure()
   )
 })
